# -*- coding: utf-8 -*-
require_relative 'base'

module BibleRef
  module Languages
    class Russian < Base
      # Is it a single chapter book?
      def has_single_chapter?(reference)
        matches = [/^авд(и[йя])?/, /^иуды?/, /^2 ?и(оа)?нн?а?/, /^3 ?и(оа)?нн?а?/, /^ф(лм|ил(имон)?у?)/]
        return Regexp.union(matches).match?(reference.downcase)
      end

      def books
        {
          'GEN' => { match: /^быт(и[её])?/,             name: 'Бытие'                 },  # Быт, Бытие
          'EXO' => { match: /^исх(од)?/,                name: 'Исход'                 },  # Исх, Исход
          'LEV' => { match: /^лев(ит)?/,                name: 'Левит'                 },  # Лев, Левит
          'NUM' => { match: /^чис(е?ла?)?/,             name: 'Числа'                 },  # Чис, Числа
          'DEU' => { match: /^втор(озаконие)?/,         name: 'Второзаконие'          },  # Втор, Второзаконие
          'JOS' => { match: /^(иисус )?нав(ин)?/,       name: 'Иисус Навин'           },  # Нав, Иисус Навин
          'JDG' => { match: /^суд(ей|ьи)/,              name: 'Судьи'                 },  # Суд, Судьи, Судей
          'RUT' => { match: /^руф[ьи]?/,                name: 'Руфь'                  },  # Руф, Руфь, Руфи
          '1SA' => { match: /^1 ?(цар(ств)?|сам(уила?)?)/, name: '1 Царств'           },  # 1 Цар, 1 Царств, 1 Сам, 1 Самуила
          '2SA' => { match: /^2 ?(цар(ств)?|сам(уила?)?)/, name: '2 Царств'           },  # 2 Цар, 2 Царств, 2 Сам, 2 Самуила
          '1KI' => { match: /^3 ?цар(ств)?/,            name: '3 Царств'              },  # 3 Цар, 3 Царств
          '2KI' => { match: /^4 ?цар(ств)?/,            name: '4 Царств'              },  # 4 Цар, 4 Царств
          '1CH' => { match: /^2 ?пар(алипоменон)/,      name: '1 Паралипоменон'       },  # 1 Пар, 1 Паралипоменон
          '2CH' => { match: /^2 ?пар(алипоменон)/,      name: '2 Паралипоменон'       },  # 2 Пар, 2 Паралипоменон
          'EZR' => { match: /^езд(р[аы])?/,             name: 'Ездра'                 },  # Ездр, Ездра, Ездры
          'NEH' => { match: /^неем(и[яи])?/,            name: 'Неемия'                },  # Неем, Неемия, Неемии
          'EST' => { match: /^[еэ]сф(ир[ьи])?/,         name: 'Есфирь'                },  # Есф, Есфирь, Есфири
          'JOB' => { match: /^иова?/,                   name: 'Иов'                   },  # Иов, Иова
          'PSA' => { match: /^пс(ал(т[ыи]рь|мы))?/,     name: 'Псалтирь'              },  # Пс, Псалтирь, Псалмы
          'PRO' => { match: /^пр(итч(и|ей))?/,          name: 'Притчи'                },  # Притч, Притчи, Притчей
          'ECC' => { match: /^[еэ]ккл(езиаста?)?/,      name: 'Екклезиаст'            },  # Еккл, Екклезиаст, Екклезиаста
          'SNG' => { match: /^пес(н[ья])?/,             name: 'Песнь песней'          },  # Пес, Песнь Песней, Песня Песен
          'ISA' => { match: /^ис(а[ий][яи])?/,          name: 'Исаия'                 },  # Ис, Исаия, Исайя, Исаии, Исайи
          'JER' => { match: /^иер(еми[яи])?/,           name: 'Иеремия'               },  # Иер, Иеремия, Иеремии
          'LAM' => { match: /^пл(ач)?( ?иер(емии)?)?/,  name: 'Плач Иеремии'          },  # Плач, Плач Иеремии
          'EZK' => { match: /^иез(екииль)?/,            name: 'Иезекииль'             },  # Иез, Иезекииль
          'DAN' => { match: /^дан(иила?)?/,             name: 'Даниил'                },  # Дан, Даниил, Даниила
          'HOS' => { match: /^ос(и[яи])?/,              name: 'Осия'                  },  # Ос, Осия, Осии
          'JOL' => { match: /^иоил([ья])?/,             name: 'Иоиль'                 },  # Иоил, Иоиль, Иоиля
          'AMO' => { match: /^ам(оса?)?/,               name: 'Амос'                  },  # Ам, Амос, Амоса
          'OBA' => { match: /^авд(и[йя])?/,             name: 'Авдий'                 },  # Авд, Авдий, Авдия
          'JON' => { match: /^ион[аы]?/,                name: 'Иона'                  },  # Ион, Иона, Ионы
          'MIC' => { match: /^мих(е[йя])?/,             name: 'Михей'                 },  # Мих, Михей, Михея
          'NAM' => { match: /^наума?/,                  name: 'Наум'                  },  # Наум, Наума
          'HAB' => { match: /^авв(акума?)?/,            name: 'Аввакум'               },  # Авв, Аввакум, Аввакума
          'ZEP' => { match: /^соф(они[яи])?/,           name: 'Софония'               },  # Соф, Софония, Софонии
          'HAG' => { match: /^агг(е[йя])?/,             name: 'Аггей'                 },  # Агг, Аггей, Аггея
          'ZEC' => { match: /^зах(ари[яи]?)/,           name: 'Захария'               },  # Зах, Захария, Захарии
          'MAL' => { match: /^мал(ахи[яи]?)/,           name: 'Малахия'               },  # Мал, Малахия, Малахии

          'TOB' => { match: /^тов(ита?)?/,              name: 'Товит'                 },  # Тов, Товит, Товита
          'JDT' => { match: /^иудиф[ьи]?/,              name: 'Иудифь'                },  # Иуд, Иудифь
          'ESG' => { match: /^[еэ]сф(ирь)? ?\(гр(еч(еская)?)?\)/, name: 'Есфирь (Греческая)'  },  # Есф (греч), Есфирь (Греческая)
          'WIS' => { match: /^прем(удрост[ьи])?( ?сол(омона)?)?/, name: 'Премудрость Соломона' },  # Прем, Премудрость Соломона
          'SIR' => { match: /^сир(аха?)?/,              name: 'Сирах'                 },  # Сир, Сирах, Сираха
          'BAR' => { match: /^вар(уха?)?/,              name: 'Варух'                 },  # Вар, Варух, Варуха
          'LJE' => { match: /^посл(ание)?( ?иер(емии)?)?/, name: 'Послание Иеремии'   },  # Посл, Послание Иеремии
          'S3Y' => { match: /^пес(н[ья]?)?( ?тр[её]х|3-?х?)( ?(свят(ых)?)?( ?отр(оков)?)?)?/, name: 'Песнь Трех Отроков' },  # Песн Трех Св.

          'SUS' => { match: /^сус(анн[аы])?/,           name: 'Сусанна'               },  # Сус, Сусанна
          'BEL' => { match: /^бел( ?и дракон)?/,        name: 'Бел и дракон'          },  # Бел, Бел и Дракон
          '1MA' => { match: /^1 ?мак(кавейская)?/,      name: '1 Маккавейская'        },  # 1 Мак, 1 Маккавейская
          '2MA' => { match: /^2 ?мак(кавейская)?/,      name: '2 Маккавейская'        },  # 2 Мак, 2 Маккавейская
          '1ES' => { match: /^1 ?ездр(ы)?/,             name: '1 Ездры'               },  # 1 Ездр, 1 Ездры
          'MAN' => { match: /^мол(итва)?( ?манассии)?/, name: 'Молитва Манассии'      },  # Мол, Молитва Манассии
          'PS2' => { match: /^пс(алом)? ?\(?151\)?/,    name: 'Псалом 151'            },  # Пс 151, Псалом 151
          '3MA' => { match: /^3 ?мак(кавейская)?/,      name: '3 Маккавейская'        },  # 3 Мак, 3 Маккавейская
          '2ES' => { match: /^2 ?езд(ры?)?/,            name: '2 Ездры'               },  # 2 Ездр, 2 Ездры
          '4MA' => { match: /^4 ?мак(кавейская)?/,      name: '4 Маккавейская'        },  # 4 Мак, 4 Маккавейская

          'MAT' => { match: /^мат(ф(е[йя])?)?|мф/,      name: 'Матфея'                },  # Мф, Мат, Матфея
          'MRK' => { match: /^мар(ка?)?|мк/,            name: 'Марка'                 },  # Мк, Марк, Марка
          'LUK' => { match: /^лук(и)?/,                 name: 'Луки'                  },  # Лк, Лук, Луки
          'JHN' => { match: /^и(оа)?нн?а?/,             name: 'Иоанна'                },  # Ин, Инн, Иоанн, Иоанна
          'ACT' => { match: /^деян(и[яй])?/,            name: 'Деяния'                },  # Деян, Деяния
          'ROM' => { match: /^рим(лянам)?/,             name: 'Римлянам'              },  # Рим, Римлянам
          '1CO' => { match: /^1 ?кор(инфянам)?/,        name: '1 Коринфянам'          },  # 1 Кор, 1 Коринфянам
          '2CO' => { match: /^2 ?кор(инфянам)?/,        name: '2 Коринфянам'          },  # 2 Кор, 2 Коринфянам
          'GAL' => { match: /^гал(атам)?/,              name: 'Галатам'               },  # Гал, Галатам
          'EPH' => { match: /^[еэ]ф(есянам)?/,          name: 'Ефесянам'              },  # Еф, Ефесянам
          'PHP' => { match: /^флп/,                     name: 'Филиппийцам'           },  # Флп, Филиппийцам
          'COL' => { match: /^кол(оссянам)?/,           name: 'Колоссянам'            },  # Кол, Колоссянам
          '1TH' => { match: /^1 ?фес(с(алоникийцам)?)?/,name: '1 Фессалоникийцам'     },  # 1 Фес, 1 Фессалоникийцам
          '2TH' => { match: /^2 ?фес(с(алоникийцам)?)?/,name: '2 Фессалоникийцам'     },  # 2 Фес, 2 Фессалоникийцам
          '1TI' => { match: /^1 ?тим(офею)?/,           name: '1 Тимофею'             },  # 1 Тим, 1 Тимофею
          '2TI' => { match: /^2 ?тим(офею)?/,           name: '2 Тимофею'             },  # 2 Тим, 2 Тимофею
          'TIT' => { match: /^титу?/,                   name: 'Титу'                  },  # Тит, Титу
          'PHM' => { match: /^флм/,                     name: 'Филимону'              },  # Флм, Филимону
          'HEB' => { match: /^евр(еям)?/,               name: 'Евреям'                },  # Евр, Евреям
          'JAS' => { match: /^иак(ова?)?/,              name: 'Иакова'                },  # Иак, Иаков, Иакова
          '1PE' => { match: /^1 ?пет(ра?)?/,            name: '1 Петра'               },  # 1 Пет, 1 Петра
          '2PE' => { match: /^2 ?пет(ра?)?/,            name: '2 Петра'               },  # 2 Пет, 2 Петра
          '1JN' => { match: /^1 ?и(оа)?нн?а?/,          name: '1 Иоанна'              },  # 1 Ин, 1 Иоанн, 1 Иоанна
          '2JN' => { match: /^2 ?и(оа)?нн?а?/,          name: '2 Иоанна'              },  # 2 Ин, 2 Иоанн, 2 Иоанна
          '3JN' => { match: /^3 ?и(оа)?нн?а?/,          name: '3 Иоанна'              },  # 3 Ин, 3 Иоанн, 3 Иоанна
          'JUD' => { match: /^иуды?/,                   name: 'Иуды'                  },  # Иуд, Иуды
          'REV' => { match: /^отк(ровение)?/,           name: 'Откровение'            }   # Откр, Откровение
        }
      end
    end
  end
end
